@@ -34,6 +34,7 @@ DolphinStatusBar::DolphinStatusBar(QWidget* parent) :
     m_text(),
     m_defaultText(),
     m_label(nullptr),
+    m_zoomLabel(nullptr),
     m_spaceInfo(nullptr),
     m_zoomSlider(nullptr),
     m_progressBar(nullptr),
@@ -48,6 +49,9 @@ DolphinStatusBar::DolphinStatusBar(QWidget* parent) :
     m_label->setWordWrap(true);
     m_label->setTextFormat(Qt::PlainText);
 
+    // Initialize zoom slider's explanatory label
+    m_zoomLabel = new QLabel(i18nc("Used as a noun, i.e. 'Here is the zoom level:'","Zoom:"), this);
+
     // Initialize zoom widget
     m_zoomSlider = new QSlider(Qt::Horizontal, this);
     m_zoomSlider->setAccessibleName(i18n("Zoom"));
@@ -100,19 +104,20 @@ DolphinStatusBar::DolphinStatusBar(QWidget* parent) :
     m_label->setFixedHeight(contentHeight);
     m_label->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
 
-    m_zoomSlider->setMaximumWidth(fontMetrics.averageCharWidth() * 25);
+    m_zoomSlider->setMaximumWidth(fontMetrics.averageCharWidth() * 15);
 
     m_spaceInfo->setFixedHeight(contentHeight);
     m_spaceInfo->setMaximumWidth(fontMetrics.averageCharWidth() * 25);
     m_spaceInfo->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
 
     m_progressBar->setFixedHeight(zoomSliderHeight);
-    m_progressBar->setMaximumWidth(fontMetrics.averageCharWidth() * 25);
+    m_progressBar->setMaximumWidth(fontMetrics.averageCharWidth() * 20);
 
     QHBoxLayout* topLayout = new QHBoxLayout(this);
     topLayout->setContentsMargins(2, 0, 2, 0);
     topLayout->setSpacing(4);
     topLayout->addWidget(m_label, 1);
+    topLayout->addWidget(m_zoomLabel);
     topLayout->addWidget(m_zoomSlider, 1);
     topLayout->addWidget(m_spaceInfo, 1);
     topLayout->addWidget(m_stopButton);
@@ -267,6 +272,7 @@ void DolphinStatusBar::contextMenuEvent(QContextMenuEvent* event)
         const bool visible = showZoomSliderAction->isChecked();
         GeneralSettings::setShowZoomSlider(visible);
         m_zoomSlider->setVisible(visible);
+        m_zoomLabel->setVisible(visible);
     } else if (action == showSpaceInfoAction) {
         const bool visible = showSpaceInfoAction->isChecked();
         GeneralSettings::setShowSpaceInfo(visible);
@@ -324,5 +330,6 @@ void DolphinStatusBar::setExtensionsVisible(bool visible)
     m_spaceInfo->setShown(showSpaceInfo);
     m_spaceInfo->setVisible(showSpaceInfo);
     m_zoomSlider->setVisible(showZoomSlider);
+    m_zoomLabel->setVisible(showZoomSlider);
 }
 
